@@ -58,11 +58,11 @@ G_BEGIN_DECLS
 /*
  * NOTES
  *
- * This is all-in-one printer configuration object
+ * This is an all-in-one printer configuration object.
  *
- * It allows several fancy tricks, and more can be implemented in future
+ * It allows several fancy tricks, and more can be implemented in future.
  *
- * Most basic usage is:
+ * The most basic usage is:
  *   config = gnome_print_config_default ();
  *   - set/get values in config
  *   - create libgnomeprintui dialogs from that config
@@ -78,24 +78,24 @@ G_BEGIN_DECLS
  *
  * Paper/Page size has been broken into different configuration
  * values.
- * Paper size or PhysicaSize referes strictly to the
+ * Paper size or PhysicalSize refers strictly to the
  * real-world paper size in printer, similarly PhysicalOrientation
  * marks, which paper side goes first into printer input tray.
- * Page size or LogicaSize refers to imaging area available to
- * application. This can conincide with physical paper size,
+ * Page size or Logical Size refers to imaging area available to
+ * application. This can coincide with the physical paper size,
  * but does not have to. Take an example:
  *   Physical A4 has always size W 210mm and H 297mm
- *   It can be fed into printer 4 different ways (PhysicalOrientations)
- *   - whatever you choose, does not affect available page
- *     size. If paper is fed in rotated way, printing subsystem
- *     rotates printed page accordingly.
+ *   It can be fed into a printer in 4 different ways (PhysicalOrientations)
+ *   - whatever you choose, does not affect the available page
+ *     size. If paper is fed in rotated way, the printing subsystem
+ *     rotates the printed page accordingly.
  *   Having Plain (1:1) layout and Landscape LOGICAL orientation
  *     changes available imaging area to W 297mm H 210mm.
  *     I.e. logical layout/orientation specifies, how your actual
  *     printed page is transferred to physical paper.
  *   Having multipage layouts make things even more complex,
  *     as your total page area may be different from paper size
- * How actual layout is calculated, is quite complex, and you
+ * How the actual layout is calculated, is quite complex, and you
  * probably want to avoid doing that in application programs.
  * There are helper methods in GnomePrintMaster, that give you
  * the only real important values needed - available imaging
@@ -104,7 +104,7 @@ G_BEGIN_DECLS
  * printout. Plain print contexts are one step lower-level, and
  * transfer printout directly to specified Physicalpage. You
  * are safe to use these, if you are 100% sure that you do not
- * want to allow multipage layouts and automatic feed orinetation
+ * want to allow multipage layouts and automatic feed orientation
  * compensation.
  *
  * ALSO
@@ -119,8 +119,8 @@ G_BEGIN_DECLS
  * Y' = X * A1 + Y * A3 + A5
  *
  * But be careful with orientation matrixes, as A4 and A5 values are
- * specified as fraction of target size in given dimension - i.e.
- * they can be either width or height, dpending on rotation used.
+ * specified as fractions of the target size in the given dimension - i.e.
+ * they can be either width or height, depending on the rotation used.
  *
  * 14/12/2001
  * Lauris Kaplinski
@@ -149,9 +149,9 @@ GnomePrintConfig *gnome_print_config_from_string (const gchar *str, guint flags)
 /*
  * Get/Set key value pairs
  *
- * All methods except gnome_print_config_get return TRUE on sucess (given
+ * All methods except gnome_print_config_get return TRUE on success (given
  * key exists and/or its value can be changed to new value), FALSE otherwise.
- * gnome_print_config_get just returns NULL, if given key does not exist.
+ * gnome_print_config_get just returns NULL, if the given key does not exist.
  *
  */
 guchar  *gnome_print_config_get         (GnomePrintConfig *config, const guchar *key);
@@ -177,6 +177,25 @@ gboolean  gnome_print_config_get_page_size (GnomePrintConfig *config, gdouble *w
  */
 void gnome_print_config_dump (GnomePrintConfig *gpc);
 
+/*
+ * Add nodes to the configuration object, experimental
+ */
+#ifdef GNOME_PRINT_UNSTABLE_API
+typedef struct _GnomePrintConfigOption GnomePrintConfigOption;
+struct _GnomePrintConfigOption {
+	const gchar *id;
+	const gchar *description;
+	gint index;
+};
+
+gboolean gnome_print_config_insert_boolean (GnomePrintConfig *config, const guchar *key,
+					    gboolean def);
+gboolean gnome_print_config_insert_options (GnomePrintConfig *config, const guchar *key,
+					    GnomePrintConfigOption *options, const gchar *def);
+
+gboolean gnome_print_config_get_option (GnomePrintConfig *config, const guchar *key,
+					GnomePrintConfigOption *options, gint *);
+#endif
 
 /*
  * Paper size
@@ -193,7 +212,6 @@ void gnome_print_config_dump (GnomePrintConfig *gpc);
 #define GNOME_PRINT_KEY_PAPER_SIZE               "Settings.Output.Media.PhysicalSize" /* Paper name, such as A4 or Letter */
 #define GNOME_PRINT_KEY_PAPER_WIDTH              "Settings.Output.Media.PhysicalSize.Width" /* Arbitrary units - use conversion */
 #define GNOME_PRINT_KEY_PAPER_HEIGHT             "Settings.Output.Media.PhysicalSize.Height" /* Arbitrary units - use conversion */
-#define GNOME_PRINT_KEY_PAPER_HEIGHT             "Settings.Output.Media.PhysicalSize.Height" /* Arbitrary units - use conversion */
 #define GNOME_PRINT_KEY_PAPER_ORIENTATION        "Settings.Output.Media.PhysicalOrientation" /* R0, R90, R180, R270 */
 #define GNOME_PRINT_KEY_PAPER_ORIENTATION_MATRIX "Settings.Output.Media.PhysicalOrientation.Paper2PrinterTransform" /* 3x2 abstract matrix */
 
@@ -233,9 +251,10 @@ void gnome_print_config_dump (GnomePrintConfig *gpc);
 #define GNOME_PRINT_KEY_PAPER_MARGIN_BOTTOM "Settings.Output.Media.Margins.Bottom" /* Length, i.e. use conversion */
 
 /* More handy keys */
-#define GNOME_PRINT_KEY_OUTPUT_FILENAME "Settings.Transport.Backend.FileName" /* Filename used when printing to file. */
-#define GNOME_PRINT_KEY_DOCUMENT_NAME "Settings.Document.Name"                /* The name of the document 'Cash flow 2002', `Grandma cookie recipies' */
-#define GNOME_PRINT_KEY_PREFERED_UNIT "Settings.Document.PreferedUnit"        /* Abbreviation for the preferred unit cm, in,... */
+#define GNOME_PRINT_KEY_OUTPUT_FILENAME "Settings.Output.Job.FileName"          /* Filename used when printing to file. */
+#define GNOME_PRINT_KEY_DOCUMENT_NAME   "Settings.Document.Name"                /* The name of the document 'Cash flow 2002', `Grandma cookie recipies' */
+#define GNOME_PRINT_KEY_PREFERED_UNIT   "Settings.Document.PreferedUnit"        /* Abbreviation for the preferred unit cm, in,... */
+
 
 G_END_DECLS
 
